==> zio-aws-iam_3-5.17.121.2-sources.jar: zio/aws/iam/model/ListServerCertificatesRequest.scala <==
package zio.aws.iam.model
import java.lang.Integer
import zio.aws.iam.model.primitives.{MaxItemsType, MarkerType, PathPrefixType}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListServerCertificatesRequest(
    pathPrefix: Option[PathPrefixType] = None,
    marker: Option[MarkerType] = None,
    maxItems: Option[MaxItemsType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest = {
    import ListServerCertificatesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
      .builder()
      .optionallyWith(
        pathPrefix.map(value => PathPrefixType.unwrap(value): java.lang.String)
      )(_.pathPrefix)
      .optionallyWith(
        marker.map(value => MarkerType.unwrap(value): java.lang.String)
      )(_.marker)
      .optionallyWith(
        maxItems.map(value => MaxItemsType.unwrap(value): Integer)
      )(_.maxItems)
      .build()
  }
  def asReadOnly: zio.aws.iam.model.ListServerCertificatesRequest.ReadOnly =
    zio.aws.iam.model.ListServerCertificatesRequest.wrap(buildAwsValue())
}
object ListServerCertificatesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.ListServerCertificatesRequest =
      zio.aws.iam.model.ListServerCertificatesRequest(
        pathPrefix.map(value => value),
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def pathPrefix: Option[PathPrefixType]
    def marker: Option[MarkerType]
    def maxItems: Option[MaxItemsType]
    def getPathPrefix: ZIO[Any, AwsError, PathPrefixType] =
      AwsError.unwrapOptionField("pathPrefix", pathPrefix)
    def getMarker: ZIO[Any, AwsError, MarkerType] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, MaxItemsType] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
  ) extends zio.aws.iam.model.ListServerCertificatesRequest.ReadOnly {
    override val pathPrefix: Option[PathPrefixType] = scala
      .Option(impl.pathPrefix())
      .map(value => zio.aws.iam.model.primitives.PathPrefixType(value))
    override val marker: Option[MarkerType] = scala
      .Option(impl.marker())
      .map(value => zio.aws.iam.model.primitives.MarkerType(value))
    override val maxItems: Option[MaxItemsType] = scala
      .Option(impl.maxItems())
      .map(value => zio.aws.iam.model.primitives.MaxItemsType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
  ): zio.aws.iam.model.ListServerCertificatesRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iam_3-5.17.205.1-sources.jar: zio/aws/iam/model/ListServerCertificatesRequest.scala <==
package zio.aws.iam.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.iam.model.primitives.{MaxItemsType, MarkerType, PathPrefixType}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListServerCertificatesRequest(
    pathPrefix: Optional[PathPrefixType] = Optional.Absent,
    marker: Optional[MarkerType] = Optional.Absent,
    maxItems: Optional[MaxItemsType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest = {
    import ListServerCertificatesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
      .builder()
      .optionallyWith(
        pathPrefix.map(value => PathPrefixType.unwrap(value): java.lang.String)
      )(_.pathPrefix)
      .optionallyWith(
        marker.map(value => MarkerType.unwrap(value): java.lang.String)
      )(_.marker)
      .optionallyWith(
        maxItems.map(value => MaxItemsType.unwrap(value): Integer)
      )(_.maxItems)
      .build()
  }
  def asReadOnly: zio.aws.iam.model.ListServerCertificatesRequest.ReadOnly =
    zio.aws.iam.model.ListServerCertificatesRequest.wrap(buildAwsValue())
}
object ListServerCertificatesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.ListServerCertificatesRequest =
      zio.aws.iam.model.ListServerCertificatesRequest(
        pathPrefix.map(value => value),
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def pathPrefix: Optional[PathPrefixType]
    def marker: Optional[MarkerType]
    def maxItems: Optional[MaxItemsType]
    def getPathPrefix: ZIO[Any, AwsError, PathPrefixType] =
      AwsError.unwrapOptionField("pathPrefix", pathPrefix)
    def getMarker: ZIO[Any, AwsError, MarkerType] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, MaxItemsType] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
  ) extends zio.aws.iam.model.ListServerCertificatesRequest.ReadOnly {
    override val pathPrefix: Optional[PathPrefixType] = zio.aws.core.internal
      .optionalFromNullable(impl.pathPrefix())
      .map(value => zio.aws.iam.model.primitives.PathPrefixType(value))
    override val marker: Optional[MarkerType] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => zio.aws.iam.model.primitives.MarkerType(value))
    override val maxItems: Optional[MaxItemsType] = zio.aws.core.internal
      .optionalFromNullable(impl.maxItems())
      .map(value => zio.aws.iam.model.primitives.MaxItemsType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.ListServerCertificatesRequest
  ): zio.aws.iam.model.ListServerCertificatesRequest.ReadOnly = new Wrapper(
    impl
  )
}
